Google Chat Baseline Report

### Secure Cloud Business Applications (SCuBA)

### Baseline Documents

# Google Chat Baseline Report

Customer Name | Customer Domain | Customer ID | Report Date | Baseline Version | Tool Version
--- | --- | --- | --- | --- | ---
Cool Example Org | example.org | ABCDEFG | 06/26/2025 16:02:22 Pacific Daylight Time | 0.5 | v0.5.0

## CHAT-1 Chat History

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.CHAT.1.1v0.5 | Chat history SHALL be enabled for information traceability. | Pass | Shall | Requirement met in all OUs and groups.
GWS.CHAT.1.2v0.5 | Users SHALL NOT be allowed to change their history setting. | Pass | Shall | Requirement met in all OUs and groups.

## CHAT-2 External File Sharing

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.CHAT.2.1v0.5 | External file sharing SHALL be disabled to protect sensitive information from unauthorized or accidental sharing. | Pass | Shall | Requirement met in all OUs and groups.

## CHAT-3 History for Spaces

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.CHAT.3.1v0.5 | Space history SHOULD be enabled for traceability of information. | Pass | Should | Requirement met in all OUs and groups.

## CHAT-4 External Chat Messaging

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.CHAT.4.1v0.5 | External Chat messaging SHALL be restricted to allowlisted domains only. | Pass | Shall | Requirement met in all OUs and groups.

## CHAT-5 Content Reporting

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.CHAT.5.1v0.5 | Chat content reporting SHALL be enabled for all conversation types. | Pass | Shall | Requirement met in all OUs and groups. WARNING: from the log events alone, it is not possible to distinguish between an OU inheriting settings from its parent and content reporting being disabled entirely. It's possible this tool classified some child OUs as compliant due to this limitation; manual check recommended for child OUs due to this edge case. Log-based check. See limitations.
GWS.CHAT.5.2v0.5 | All reporting message categories SHOULD be selected. | Pass | Should | Requirement met in all OUs and groups. Log-based check. See limitations.